==> jc-1.4.0.tar.gz: soot/dava/internal/javaRep/DIntConstant.h <==
// public class soot.dava.internal.javaRep.DIntConstant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2464f03d5ed5f08c soot_dava_internal_javaRep_DIntConstant
// @dep_class e5651dde6cd08af9 soot_jimple_ArithmeticConstant
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class fade60ef604ad800 soot_jimple_IntConstant
// @dep_class 3bd9379d3ff77f81 soot_jimple_NumericConstant

// header file dependencies
// @dep_header soot_jimple_IntConstant

#include "soot/jimple/IntConstant.h"

#ifndef _JC_soot_dava_internal_javaRep_DIntConstant_H_
#define _JC_soot_dava_internal_javaRep_DIntConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_dava_internal_javaRep_DIntConstant$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DIntConstant$sub_refs	_jc_soot_dava_internal_javaRep_DIntConstant$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DIntConstant$sub_nonrefs	_jc_soot_dava_internal_javaRep_DIntConstant$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DIntConstant$refs	_jc_soot_dava_internal_javaRep_DIntConstant$refs;
typedef struct _jc_soot_dava_internal_javaRep_DIntConstant$nonrefs	_jc_soot_dava_internal_javaRep_DIntConstant$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DIntConstant$object	_jc_soot_dava_internal_javaRep_DIntConstant$object;

typedef const struct _jc_soot_dava_internal_javaRep_DIntConstant$vmethods	_jc_soot_dava_internal_javaRep_DIntConstant$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DIntConstant$vtable	_jc_soot_dava_internal_javaRep_DIntConstant$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DIntConstant$vtype	_jc_soot_dava_internal_javaRep_DIntConstant$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DIntConstant$method$_init$f39a30cdd46da6e9(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIntConstant$object *, jint, struct _jc_soot_Type$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DIntConstant$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIntConstant$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DIntConstant$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_dava_internal_javaRep_DIntConstant$object *_jc_soot_dava_internal_javaRep_DIntConstant$method$v$0da5b5850146e573(_jc_env *, jint, struct _jc_soot_Type$object *);

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DIntConstant$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIntConstant$object *);
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DIntConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_jimple_NumericConstant$vmethods	soot_jimple_NumericConstant;
	_jc_soot_jimple_ArithmeticConstant$vmethods	soot_jimple_ArithmeticConstant;
	_jc_soot_jimple_IntConstant$vmethods	soot_jimple_IntConstant;
	_jc_soot_dava_internal_javaRep_DIntConstant$vmethods	soot_dava_internal_javaRep_DIntConstant;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DIntConstant$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DIntConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DIntConstant$sub_refs {
	struct _jc_soot_Type$object	*type;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DIntConstant$refs {
    _jc_soot_dava_internal_javaRep_DIntConstant$sub_refs	soot_dava_internal_javaRep_DIntConstant;
    _jc_soot_jimple_IntConstant$sub_refs	soot_jimple_IntConstant;
    _jc_soot_jimple_ArithmeticConstant$sub_refs	soot_jimple_ArithmeticConstant;
    _jc_soot_jimple_NumericConstant$sub_refs	soot_jimple_NumericConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DIntConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DIntConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_jimple_NumericConstant$sub_nonrefs	soot_jimple_NumericConstant;
    _jc_soot_jimple_ArithmeticConstant$sub_nonrefs	soot_jimple_ArithmeticConstant;
    _jc_soot_jimple_IntConstant$sub_nonrefs	soot_jimple_IntConstant;
    _jc_soot_dava_internal_javaRep_DIntConstant$sub_nonrefs	soot_dava_internal_javaRep_DIntConstant;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DIntConstant$object {
	_jc_soot_dava_internal_javaRep_DIntConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DIntConstant$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DIntConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DIntConstant$vtype _jc_soot_dava_internal_javaRep_DIntConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DIntConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DIntConstant$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DIntConstant_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/javaRep/DIntConstant.h <==
// public class soot.dava.internal.javaRep.DIntConstant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2464f03d5ed5f08c soot_dava_internal_javaRep_DIntConstant
// @dep_class e5651dde6cd08af9 soot_jimple_ArithmeticConstant
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class fade60ef604ad800 soot_jimple_IntConstant
// @dep_class 3bd9379d3ff77f81 soot_jimple_NumericConstant

// header file dependencies
// @dep_header soot_jimple_IntConstant

#include "soot/jimple/IntConstant.h"

#ifndef _JC_soot_dava_internal_javaRep_DIntConstant_H_
#define _JC_soot_dava_internal_javaRep_DIntConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_dava_internal_javaRep_DIntConstant$object;

// Typedefs
typedef struct _jc_soot_dava_internal_javaRep_DIntConstant$sub_refs	_jc_soot_dava_internal_javaRep_DIntConstant$sub_refs;
typedef struct _jc_soot_dava_internal_javaRep_DIntConstant$sub_nonrefs	_jc_soot_dava_internal_javaRep_DIntConstant$sub_nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DIntConstant$refs	_jc_soot_dava_internal_javaRep_DIntConstant$refs;
typedef struct _jc_soot_dava_internal_javaRep_DIntConstant$nonrefs	_jc_soot_dava_internal_javaRep_DIntConstant$nonrefs;
typedef struct _jc_soot_dava_internal_javaRep_DIntConstant$object	_jc_soot_dava_internal_javaRep_DIntConstant$object;

typedef const struct _jc_soot_dava_internal_javaRep_DIntConstant$vmethods	_jc_soot_dava_internal_javaRep_DIntConstant$vmethods;
typedef const struct _jc_soot_dava_internal_javaRep_DIntConstant$vtable	_jc_soot_dava_internal_javaRep_DIntConstant$vtable;
typedef const struct _jc_soot_dava_internal_javaRep_DIntConstant$vtype	_jc_soot_dava_internal_javaRep_DIntConstant$vtype;

// Constructors
extern void _jc_soot_dava_internal_javaRep_DIntConstant$method$_init$f39a30cdd46da6e9(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIntConstant$object *, jint, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_dava_internal_javaRep_DIntConstant$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIntConstant$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_javaRep_DIntConstant$method_info$toString$7ea43b33b80a3070;

// Static methods
extern struct _jc_soot_dava_internal_javaRep_DIntConstant$object *_jc_soot_dava_internal_javaRep_DIntConstant$method$v$0da5b5850146e573(_jc_env *, jint, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_dava_internal_javaRep_DIntConstant$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_dava_internal_javaRep_DIntConstant$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_javaRep_DIntConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_jimple_NumericConstant$vmethods	soot_jimple_NumericConstant;
	_jc_soot_jimple_ArithmeticConstant$vmethods	soot_jimple_ArithmeticConstant;
	_jc_soot_jimple_IntConstant$vmethods	soot_jimple_IntConstant;
	_jc_soot_dava_internal_javaRep_DIntConstant$vmethods	soot_dava_internal_javaRep_DIntConstant;
};

// Vtype
struct _jc_soot_dava_internal_javaRep_DIntConstant$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_javaRep_DIntConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DIntConstant$sub_refs {
	struct _jc_soot_Type$object	*type;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DIntConstant$refs {
    _jc_soot_dava_internal_javaRep_DIntConstant$sub_refs	soot_dava_internal_javaRep_DIntConstant;
    _jc_soot_jimple_IntConstant$sub_refs	soot_jimple_IntConstant;
    _jc_soot_jimple_ArithmeticConstant$sub_refs	soot_jimple_ArithmeticConstant;
    _jc_soot_jimple_NumericConstant$sub_refs	soot_jimple_NumericConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_javaRep_DIntConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_javaRep_DIntConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_jimple_NumericConstant$sub_nonrefs	soot_jimple_NumericConstant;
    _jc_soot_jimple_ArithmeticConstant$sub_nonrefs	soot_jimple_ArithmeticConstant;
    _jc_soot_jimple_IntConstant$sub_nonrefs	soot_jimple_IntConstant;
    _jc_soot_dava_internal_javaRep_DIntConstant$sub_nonrefs	soot_dava_internal_javaRep_DIntConstant;
};

// Object instance structure
struct _jc_soot_dava_internal_javaRep_DIntConstant$object {
	_jc_soot_dava_internal_javaRep_DIntConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_javaRep_DIntConstant$vtype	*vtype;
	_jc_soot_dava_internal_javaRep_DIntConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_javaRep_DIntConstant$vtype _jc_soot_dava_internal_javaRep_DIntConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_javaRep_DIntConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_javaRep_DIntConstant$class_object;

#endif	/* _JC_soot_dava_internal_javaRep_DIntConstant_H_ */
